
Credits
=======

Development Lead
----------------
* Ag Stephens ag.stephens@stfc.ac.uk

Co-Developers
-------------

* Eleanor Smith eleanor.smith@stfc.ac.uk `@ellesmith88 <https://github.com/ellesmith88>`_
* Carsten Ehbrecht ehbrecht@dkrz.de
* Pascal Bourgault pascal.bourgault@gmail.com

Contributors
------------

* Martin Schupfner <schupfner@dkrz.de> `@sol1105 <https://github.com/sol1105>`_
